Rucio Exceptions — Rucio 1.2 documentation

# Rucio Exceptions

Exceptions used with Rucio.

The base exception class is `RucioException`. Exceptions which are raised are all subclasses of it.

exception `rucio.common.exception.` `AccessDenied`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `AccountNotFound`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `CannotAuthenticate`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `ClientParameterMismatch`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `ClientProtocolNotSupported`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `ConfigNotFound`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `ConfigurationError`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `CounterNotFound`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `DataIdentifierAlreadyExists`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `DataIdentifierNotFound`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `DatabaseException`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `DestinationNotAccessible`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `Duplicate`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `DuplicateContent`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `DuplicateRule`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `ErrorLoadingCredentials`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `FileAlreadyExists`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `FileConsistencyMismatch`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `FileReplicaAlreadyExists`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `FullStorage`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `IdentityError`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `IdentityNotFound`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `InputValidationError`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `InsufficientAccountLimit`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `InsufficientTargetRSEs`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `InvalidMetadata`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `InvalidObject`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `InvalidPath`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `InvalidRSEExpression`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `InvalidReplicationRule`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `InvalidRequest`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `InvalidRuleWeight`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `InvalidType`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `InvalidValueForKey`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `KeyNotFound`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `LifetimeExceptionDuplicate`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `LifetimeExceptionNotFound`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `ManualRuleApprovalBlocked`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `MissingClientParameter`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `MissingDependency`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `MissingModuleException`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `MissingSourceReplica`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `NameTypeError`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `NoAuthInformation`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `NoFilesDownloaded`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `NoFilesUploaded`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `NotAllFilesDownloaded`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `NotAllFilesUploaded`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `RSEAccessDenied`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `RSEBlacklisted`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `RSEChecksumUnavailable`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

  Cannot retrieve checksum from RSE

exception `rucio.common.exception.` `RSEFileNameNotSupported`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `RSENotConnected`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `RSENotFound`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `RSEOperationNotSupported`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `RSEOverQuota`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `RSEProtocolDomainNotSupported`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `RSEProtocolNotSupported`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `RSEProtocolPriorityError`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `ReplicaNotFound`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `ReplicaUnAvailable`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `ReplicationRuleCreationTemporaryFailed`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `RequestNotFound`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `ResourceTemporaryUnavailable`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `RucioException`(*args, **kwargs)

  Bases: `exceptions.Exception`

  To correctly use this class, inherit from it and define a ‘message’ property. That message will get printf’d with the keyword arguments provided to the constructor.

exception `rucio.common.exception.` `RuleNotFound`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `RuleReplaceFailed`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `ScopeAccessDenied`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `ScopeNotFound`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `ScratchDiskLifetimeConflict`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `ServerConnectionException`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `ServiceUnavailable`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `SourceAccessDenied`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `SourceNotFound`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `StagingAreaRuleRequiresLifetime`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `SubscriptionDuplicate`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `SubscriptionNotFound`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `TransferToolTimeout`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

  Timeout from the transfer tool

exception `rucio.common.exception.` `TransferToolWrongAnswer`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

  Wrong answer returned by the transfer tool

exception `rucio.common.exception.` `UndefinedPolicy`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

  Cannot find a defined policy in the Rucio config

exception `rucio.common.exception.` `UnsupportedDIDType`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `UnsupportedOperation`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `UnsupportedStatus`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`

exception `rucio.common.exception.` `UnsupportedValueType`(*args, **kwargs)

  Bases: `rucio.common.exception.RucioException`